@@ -1,4 +1,6 @@
+# SPDX-License-Identifier: GPL-2.0-only
 import errno
+import os
 import gi
 gi.require_version("Gtk", "3.0")
 from gi.repository import GObject
@@ -66,6 +68,9 @@ def thread_set_attributes(pid_info, new_policy, new_prio, new_affinity, nr_cpus)
     curr_prio = int(pid_info["stat"]["rt_priority"])
     if new_policy == os.SCHED_OTHER:
         new_prio = 0
+    if new_policy == os.SCHED_FIFO or new_policy == os.SCHED_RR:
+        if not new_prio:
+            new_prio = 1
     if curr_policy != new_policy or curr_prio != new_prio:
         param = os.sched_param(new_prio)
         try:
@@ -80,6 +85,7 @@ def thread_set_attributes(pid_info, new_policy, new_prio, new_affinity, nr_cpus)
             dialog.destroy()
             return False
 
+
         curr_policy = os.sched_getscheduler(pid)
         if curr_policy != new_policy:
             print(_("couldn't change pid %(pid)d from %(cpol)s(%(cpri)d) to %(npol)s(%(npri)d)!") % \
@@ -91,7 +97,7 @@ def thread_set_attributes(pid_info, new_policy, new_prio, new_affinity, nr_cpus)
             changed = True
 
     try:
-        curr_affinity = os.sched_getaffinity(pid)
+        curr_affinity = list(os.sched_getaffinity(pid))
     except OSError as err:
         if err.args[0] == errno.ESRCH:
             return False
@@ -114,7 +120,7 @@ def thread_set_attributes(pid_info, new_policy, new_prio, new_affinity, nr_cpus)
             return invalid_affinity()
 
         try:
-            curr_affinity = os.sched_getaffinity(pid)
+            curr_affinity = list(os.sched_getaffinity(pid))
         except OSError as err:
             if err.args[0] == errno.ESRCH:
                 return False
